#############################################################################
#############################################################################
###############                                                    ##########
###############       Cognitive Ability and Risk Aversion:         ##########
###############  A systematic Literature Review and Meta-Analysis  ##########
###############                                                    ##########
###############                  (Males Only)                      ##########
###############                                                    ##########
###############                                                    ##########
#############################################################################
#############################################################################


#############################################################################
##                                                                         ##
##  This R-script replicates the results from the paper:"Cognitive Ability ##
##  and Risk Aversion: A systematic Review and Meta-Analysis".             ##
##                                                                         ##
#############################################################################


###############################
##      Load packages        ##
###############################

library("metafor")
library("dplyr")
library("readxl")


################################################ 
## Set working directory to data file path....## 
################################################

setwd("~/Documents/Articles/Cognitive Ability & Risk Aversion (JDM)/Final Resubmission")


####################
## Load data....  ##
####################  

Data_Gains<- read_excel("Final_Data_Gains.xlsx", 
                        col_types = c("text", "numeric", 
                                      "numeric", "numeric", "numeric", 
                                      "numeric", "numeric", "numeric", 
                                      "numeric", "text", "text", "numeric", 
                                      "text", "text", "text", "text", "text", 
                                      "text", "text", "numeric", "text", 
                                      "text", "numeric", "numeric", "numeric", 
                                      "numeric", "numeric", "numeric", 
                                      "text", "text", "text", "text", "text"))


Data_Mixed <- read_excel("Final_Data_Mixed.xlsx",
                         col_types = c("text", "numeric", 
                                       "numeric", "numeric", "numeric", 
                                       "numeric", "numeric", "numeric", 
                                       "numeric", "text", "text", "numeric", 
                                       "text", "text", "text", "text", "text", 
                                       "text", "text", "numeric", "text", 
                                       "text", "numeric", "numeric", "numeric", 
                                       "numeric", "numeric", "numeric", 
                                       "text", "text", "text", "text", "text"))



Data_Losses <- read_excel("Final_Data_Losses.xlsx", 
                          col_types = c("text", "numeric", 
                                        "numeric", "numeric", "numeric", 
                                        "numeric", "numeric", "numeric", 
                                        "numeric", "text", "text", "numeric", 
                                        "text", "text", "text", "text", "text", 
                                        "text", "text", "numeric", "text", 
                                        "text", "numeric", "numeric", "numeric", 
                                        "numeric", "numeric", "numeric", 
                                        "text", "text", "text", "text", "text"))



#####################  
# Z-Transformation ## 
#####################

Data_Gains<- escalc(measure= "ZCOR", ri= `R_Male_Recode`, ni= `Male`, 
                    data=Data_Gains, 
                    slab=paste(Author, Year))

Data_Mixed<- escalc(measure= "ZCOR", ri= `R_Male_Recode`, ni= `Male`, 
                    data=Data_Mixed, 
                    slab=paste(Author, Year))


Data_Losses<- escalc(measure= "ZCOR", ri= `R_Male_Recode`, ni= `Male`, 
                     data=Data_Losses, 
                     slab=paste(Author, Year))   

##################################################  
## Random-Effect Meta-Analysis Gains Males Only ##   
##################################################  

Res_Gain_Male <- rma(yi, vi, data=Data_Gains, method = "REML") 
Res_Gain_Male 
predict(Res_Gain_Male, digits=2, transf=transf.ztor)
confint(Res_Gain_Male)  



##########################################    
## Influential Studies Gains Males Only ##  
########################################## 

Inf_Gain_Male <- influence(Res_Gain_Male)
print(Inf_Gain_Male, digits=2) 
plot(Inf_Gain_Male)
plot(Inf_Gain_Male, plotdfb = TRUE)
leave1out(Res_Gain_Male, digits = 3)



##################################  
## Forest Plot Gains Males Only ##  
##################################  

forest(Res_Gain_Male)


#######################################
## Publication Bias Gains Males Only ##     
####################################### 

funnel(Res_Gain_Male)
regtest(Res_Gain_Male)
ranktest(Res_Gain_Male)



#########################################
## Moderator Analysis Gains Males Only ##    
#########################################  


Res_Gain_Sample_Type_Male <-rma(yi, vi, mods = ~ factor(Sample_Type), data=Data_Gains, method = "REML")
Res_Gain_Sample_Type_Male

Res_Gain_Avrg_Pay_Male <- rma(yi, vi, mods = ~ Avrg_Pay_., data=Data_Gains, method = "REML")
Res_Gain_Avrg_Pay_Male

Res_Gain_CAM_Male <- rma(yi, vi, mods = ~ factor(CAM), data=Data_Gains, method = "REML") 
Res_Gain_CAM_Male  

Res_Gain_Decision_Task_Male <- rma(yi, vi, mods = ~ factor(Decision_Task), data=Data_Gains, method = "REML") 
Res_Gain_Decision_Task_Male

Res_Gain_Certain_Option_Male <- rma(yi, vi, mods = ~ factor(Certain_Option), data=Data_Gains, method = "REML")
Res_Gain_Certain_Option_Male

Res_Gain_Probabilities_Male <- rma(yi, vi, mods = ~ factor(Probabilities), data=Data_Gains, method = "REML")
Res_Gain_Probabilities_Male

Res_Gain_Payoff_Safer_Choice_Male <- rma(yi, vi, mods = ~ factor(Payoff_Safer_Choice), data=Data_Gains, method = "REML")
Res_Gain_Payoff_Safer_Choice_Male

Res_Gain_Payoff_Riskier_Choice_Male <- rma(yi, vi, mods = ~ factor(Payoff_Riskier_Choice), data=Data_Gains, method = "REML")
Res_Gain_Payoff_Riskier_Choice_Male

Res_Gain_Incentivized_Male <-rma(yi, vi, mods = ~ factor(Incentivized), data=Data_Gains, method = "REML")
Res_Gain_Incentivized_Male

Res_Gain_Possible_RA_Choices_Male <- rma(yi, vi, mods = ~ X._Possible_RA_Choices , data=Data_Gains, method = "REML")
Res_Gain_Possible_RA_Choices_Male

Res_Gain_Primary_Purpose_Male <- rma(yi, vi, mods = ~ factor(Primary_Purpose), data=Data_Gains, method = "REML")
Res_Gain_Primary_Purpose_Male

Res_Gain_Imputed_Beta_Male <-rma(yi, vi, mods = ~ factor(Imputed_Beta), data=Data_Gains, method = "REML")
Res_Gain_Imputed_Beta_Male 


##################################################  
## Random-Effect Meta-Analysis Mixed Males Only ##   
##################################################  

Res_Mixed_Male <- rma(yi, vi, data=Data_Mixed, method = "REML") 
Res_Mixed_Male 
predict(Res_Mixed_Male, digits=2, transf=transf.ztor)
confint(Res_Mixed_Male)  



##########################################    
## Influential Studies Mixed Males Only ##  
########################################## 

Inf_Mixed_Male <- influence(Res_Mixed_Male)
print(Inf_Mixed_Male, digits=2)
plot(Inf_Mixed_Male)
plot(Inf_Mixed_Male, plotdfb = TRUE)



##################################  
## Forest Plot Mixed Males Only ##  
##################################  

forest(Res_Mixed_Male)  


#######################################
## Publication Bias Mixed Males Only ##     
####################################### 

funnel(Res_Mixed_Male)
regtest(Res_Mixed_Male)
ranktest(Res_Mixed_Male)


##########################################
## Moderator Analysis Mixed  Males Only ##    
##########################################   

Res_Mixed_Sample_Type_Male <-rma(yi, vi, mods = ~ factor(Sample_Type), data=Data_Mixed, method = "REML")
Res_Mixed_Sample_Type_Male

Res_Mixed_Avrg_Pay_Male <- rma(yi, vi, mods = ~ Avrg_Pay_., data=Data_Mixed, method = "REML")
Res_Mixed_Avrg_Pay_Male

Res_Mixed_CAM_Male <- rma(yi, vi, mods = ~ factor(CAM), data=Data_Mixed, method = "REML") 
Res_Mixed_CAM_Male  

Res_Mixed_Decision_Task_Male <- rma(yi, vi, mods = ~ factor(Decision_Task), data=Data_Mixed, method = "REML") 
Res_Mixed_Decision_Task_Male

Res_Mixed_Certain_Option_Male <- rma(yi, vi, mods = ~ factor(Certain_Option), data=Data_Mixed, method = "REML")
Res_Mixed_Certain_Option_Male

Res_Mixed_Probabilities_Male <- rma(yi, vi, mods = ~ factor(Probabilities), data=Data_Mixed, method = "REML")
Res_Mixed_Probabilities_Male

Res_Mixed_Payoff_Safer_Choice_Male <- rma(yi, vi, mods = ~ factor(Payoff_Safe_Choice), data=Data_Mixed, method = "REML")
Res_Mixed_Payoff_Safer_Choice_Male

Res_Mixed_Payoff_Riskier_Choice_Male <- rma(yi, vi, mods = ~ factor(Payoff_Risky_Choice), data=Data_Mixed, method = "REML")
Res_Mixed_Payoff_Riskier_Choice_Male

Res_Mixed_Incentivized_Male <-rma(yi, vi, mods = ~ factor(Incentivized), data=Data_Mixed, method = "REML")
Res_Mixed_Incentivized_Male

Res_Mixed_Possible_RA_Choices_Male <- rma(yi, vi, mods = ~ X._Possible_RA_Choices , data=Data_Mixed, method = "REML")
Res_Mixed_Possible_RA_Choices_Male

Res_Mixed_Primary_Purpose_Male <- rma(yi, vi, mods = ~ factor(Primary_Purpose), data=Data_Mixed, method = "REML")
Res_Mixed_Primary_Purpose_Male

Res_Mixed_Imputed_Beta_Male <-rma(yi, vi, mods = ~ factor(Imputed_Beta), data=Data_Mixed, method = "REML")
Res_Mixed_Imputed_Beta_Male 



###################################################  
## Random-Effect Meta-Analysis Losses Males Only ##   
###################################################  

Res_Losses_Male <- rma(yi, vi, data=Data_Losses, method = "REML") 
Res_Losses_Male 
predict(Res_Losses_Male, digits=2, transf=transf.ztor)
confint(Res_Losses_Male)  



###########################################    
## Influential Studies Losses Males Only ##  
########################################### 


Inf_Losses_Male <- influence(Res_Losses_Male)
print(Inf_Losses_Male, digits=2)
plot(Inf_Losses_Male)
plot(Inf_Losses_Male, plotdfb = TRUE)
leave1out(Res_Losses_Male, digits = 3)




####################################  
## Forest Plot Losses Males Only  ##  
####################################  

forest(Res_Losses_Male)


########################################
## Publication Bias Losses Males Only ##     
######################################## 

funnel(Res_Losses_Male)
regtest(Res_Losses_Male)
ranktest(Res_Losses_Male)



##########################################
## Moderator Analysis Losses Males Only ##    
########################################## 

Res_Losses_Sample_Type_Male <-rma(yi, vi, mods = ~ factor(Sample_Type), data=Data_Losses, method = "REML")
Res_Losses_Sample_Type_Male

Res_Losses_Avrg_Pay_Male <- rma(yi, vi, mods = ~ Avrg_Pay_., data=Data_Losses, method = "REML")
Res_Losses_Avrg_Pay_Male

Res_Losses_CAM_Male <- rma(yi, vi, mods = ~ factor(CAM), data=Data_Losses, method = "REML") 
Res_Losses_CAM_Male  

Res_Losses_Decision_Task_Male <- rma(yi, vi, mods = ~ factor(Decision_Task), data=Data_Losses, method = "REML") 
Res_Losses_Decision_Task_Male

Res_Losses_Certain_Option_Male <- rma(yi, vi, mods = ~factor(Certain_Option), data=Data_Losses, method = "REML")
Res_Losses_Certain_Option_Male

Res_Losses_Probabilities_Male <- rma(yi, vi, mods = ~ factor(Probabilities), data=Data_Losses, method = "REML")
Res_Losses_Probabilities_Male

Res_Losses_Payoff_Safer_Choice_Male <- rma(yi, vi, mods = ~ factor(Payoff_Safe_Choice), data=Data_Losses, method = "REML")
Res_Losses_Payoff_Safer_Choice_Male

Res_Losses_Payoff_Riskier_Choice_Male <- rma(yi, vi, mods = ~ factor(Payoff_Risky_Choice), data=Data_Losses, method = "REML")
Res_Losses_Payoff_Riskier_Choice_Male

Res_Losses_Incentivized_Male <-rma(yi, vi, mods = ~ factor(Incentivized), data=Data_Losses, method = "REML")
Res_Losses_Incentivized_Male

Res_Losses_Possible_RA_Choices_Male <- rma(yi, vi, mods = ~ X._Possible_RA_Choices , data=Data_Losses, method = "REML")
Res_Losses_Possible_RA_Choices_Male

Res_Losses_Primary_Purpose_Male <- rma(yi, vi, mods = ~ factor(Primary_Purpose), data=Data_Losses, method = "REML")
Res_Losses_Primary_Purpose_Male

Res_Losses_Imputed_Beta_Male <-rma(yi, vi, mods = ~ factor(Imputed_Beta), data=Data_Losses, method = "REML")
Res_Losses_Imputed_Beta_Male 









