#############################################################################
#############################################################################
###############                                                    ##########
###############       Cognitive Ability and Risk Aversion:         ##########
###############  A systematic Literature Review and Meta-Analysis  ##########
###############                                                    ##########
#############################################################################
#############################################################################


#############################################################################
##                                                                         ##
##  This R-script replicates the figures from the paper:"Cognitive Ability ##
##  and Risk Aversion: A systematic Review and Meta-Analysis".             ##
##                                                                         ##
#############################################################################


#############################################################################                                                                      
##  Please note that you need to run the following scripts before running  ##
##  this script to create the figures:                                     ##
##                                                                         ##
##    (1) Cognitive Ability and Risk Aversion A Systematic Review and      ##
##        Meta-Analysis.R                                                  ##
##                                                                         ##
##    (2) Cognitive Ability and Risk Aversion A Systmeatic Review and      ##
##        Meta-Analysis - Males Only.R                                     ##
##                                                                         ##
##    (3) Cognitive Ability and Risk Aversion A Systmeatic Review and      ##
##        Meta-Analysis - Females Only.R                                   ##
##                                                                         ##
#############################################################################


#############################################################################
#                        Install and load Packages                          #
#############################################################################

  #install.packages("R.utils")
  library(R.utils)


####################################################################################################
## Figure 2. Forest Plots for the Domain of Gains – Full Sample, Males and Females Only  - Part 1 ##
####################################################################################################
 
 setEPS(family = "Times") 
 postscript("Figure 2.1. Forest Plots for the Domain of Gains – Full Sample.eps", width = 7, height = 13, horizontal = FALSE) # The width and height can be adjusted here! 
 par(family="Times")  
 layout(matrix(c(
                1, 
                1, 
                1, 
                1, 
                1, 
                1,
                1), nrow=7, byrow=TRUE))
  forest(Res_Gain, xlab = "Full Sample", cex = 1)
  text(-2.35, 98.5, "Author(s) and Year", pos=4, cex = 1)
  text( 2.2, 98.5, "Correlation Coefficient [95% CI]", pos=2, cex = 1)
  dev.off() 
  


####################################################################################################
## Figure 2. Forest Plots for the Domain of Gains – Full Sample, Males and Females Only  - Part 2 ##
####################################################################################################
  
  setEPS(family = "Times") 
  postscript("Figure 2.2. Forest Plots for the Domain of Gains – Males and Females Only.eps", width = 9, height = 8, horizontal = FALSE) # The width and height can be adjusted here! 
  par(family="Times")
  layout(matrix(c(
    1, 2,
    1, 2, 
    1, 2, 
    1, 2,
    1, 2, 
    1, 2,
    1, 2), nrow=7, byrow=TRUE))
  forest(Res_Gain_Male, xlab = "Males Only", cex = 1)
  text(-3, 52.5, "Author(s) and Year", pos=4, cex = 1)
  text( 3.1, 52.5, "Correlation Coefficient [95% CI]", pos=2, cex = 1)
  forest(Res_Gain_Female, xlab = "Females Only", cex = 1)
  text(-3, 49.5, "Author(s) and Year", pos=4, cex = 1)
  text( 2.6,49.5, "Correlation Coefficient [95% CI]", pos=2, cex = 1)
  dev.off() 
  
  
###################################################################################################
## Figure 3. Forest Plots for the Mixed Domain – Full Sample, Males and Females Only  - Part 1   ##
###################################################################################################
  
  setEPS(family = "Times") 
  postscript("Figure 3.1. Forest Plots for the Mixed Domain – Full Sample.eps", width = 6, height = 6, horizontal = FALSE) # The width and height can be adjusted here! 
  par(family="Times")
  layout(matrix(c(
    1,
    1,
    1,
    1, 
    1, 
    1), nrow=6, byrow=TRUE))
  forest(Res_Mixed, xlab = "Full Sample", cex = 1)
  text(-1.35, 42.5, "Author(s) and Year", pos=4, cex = 1)
  text( 1.35, 42.5, "Correlation Coefficient [95% CI]", pos=2, cex = 1)
  dev.off() 
  
###################################################################################################
## Figure 3. Forest Plots for the Mixed Domain – Full Sample, Males and Females Only  - Part 2   ##
###################################################################################################
  
  setEPS(family = "Times") 
  postscript("Figure 3.2. Forest Plots for the Mixed Domain – Males and Females Only.eps", width = 9, height = 5, horizontal = FALSE) # The width and height can be adjusted here! 
  par(family="Times")
  layout(matrix(c(
    1, 2, 
    1, 2, 
    1, 2, 
    1, 2, 
    1, 2, 
    1, 2), nrow=6, byrow=TRUE))
  forest(Res_Mixed_Male, xlab = "Males Only", cex = 1)
  text(-1.8, 25.4, "Author(s) and Year", pos=4, cex = 1)
  text( 1.7, 25.4, "Correlation Coefficient [95% CI]", pos=2, cex = 1)
  forest(Res_Mixed_Female, xlab = "Females Only", cex = 1)
  text(-2.1, 25.4, "Author(s) and Year", pos=4, cex = 1)
  text( 2.05, 25.4, "Correlation Coefficient [95% CI]", pos=2, cex = 1)
  dev.off() 
  

  
  
#####################################################################################################
## Figure 4. Forest Plots for the Domain of Losses – Full Sample, Males and Females Only - Part 1  ##
####################################################################################################
  
  setEPS(family = "Times") 
  postscript("Figure 4.1. Forest Plots for the Domain of Losses – Full Sample.eps", width = 5, height = 3.5, horizontal = FALSE) # The width and height can be adjusted here! 
  par(family="Times")
  layout(matrix(c(
    1,  
    1,  
    1,  
    1,  
    1,  
    1), nrow=6, byrow=TRUE))
  forest(Res_Losses, cex = 1, xlab = "Full Sample")
  text(-1.7, 13.4, "Author(s) and Year", pos=4, cex = 1)
  text( 1.3, 13.4, "Correlation Coefficient [95% CI]", pos=2, cex = 1)
  dev.off() 
  
#####################################################################################################
## Figure 4. Forest Plots for the Domain of Losses – Full Sample, Males and Females Only - Part 2  ##
####################################################################################################
  
  setEPS(family = "Times") 
  postscript("Figure 4.2. Forest Plots for the Domain of Losses – Males and Females Only.eps", width = 9, height = 3, horizontal = FALSE) # The width and height can be adjusted here! 
  par(family="Times")
  layout(matrix(c(
    1, 2,
    1, 2, 
    1, 2, 
    1, 2, 
    1, 2,
    1, 2), nrow=6, byrow=TRUE))
  forest(Res_Losses_Male, xlab = "Males Only", cex = 1, cex.sub= 1)
  text(-2.1, 9.4, "Author(s) and Year", pos=4, cex = 1)
  text( 1.65, 9.4, "Correlation Coefficient [95% CI]", pos=2, cex = 1)
  forest(Res_Losses_Female, xlab = "Females Only", cex = 1)
  text(-1.55, 9.4, "Author(s) and Year", pos=4, cex = 1)
  text( 1.35, 9.4, "Correlation Coefficient [95% CI]", pos=2, cex = 1)
  dev.off() 
  
  

###########################################################################################
## Figure 5. Funnel Plots for the Domain of Gains – Full Sample, Males and Females Only  ##
###########################################################################################
 
  setEPS(family = "Times") 
  postscript("Figure 5. Funnel Plots for the Domain of Gains – Full Sample, Males and Females Only.eps", width = 8, height = 4, horizontal = FALSE) # The width and height can be adjusted here! 
  par(family="Times")
  layout(matrix(c(1,2,3), nrow=1, byrow=TRUE))
  funnel(Res_Gain, main= "\nFull Sample")
  funnel(Res_Gain_Male, main = "\nMales Only")
  funnel(Res_Gain_Female, main = "\nFemales Only")
  dev.off() 


  
###########################################################################################
## Figure 6. Funnel Plots for the Mixed Domain – Full Sample, Males and Females Only     ##
###########################################################################################
  
  setEPS(family = "Times") 
  postscript("Figure 6. Funnel Plots for the Mixed Domain – Full Sample, Males and Females Only.eps", width = 8, height = 4, horizontal = FALSE) # The width and height can be adjusted here! 
  par(family="Times")
  layout(matrix(c(1,2,3), nrow=1, byrow=TRUE))
  funnel(Res_Mixed, main= "\nFull Sample")
  funnel(Res_Mixed_Male, main = "\nMales Only")
  funnel(Res_Mixed_Female, main = "\nFemales Only")
  dev.off() 

  



###########################################################################################
## Figure 7. Funnel Plot for the Domain of Losses – Full Sample, Males and Females Only  ##
###########################################################################################
  
  setEPS(family = "Times") 
  postscript("Figure 7. Funnel Plot for the Domain of Losses – Full Sample, Males and Females Only .eps", width = 8, height = 4, horizontal = FALSE) # The width and height can be adjusted here!  
  par(family="Times")
  layout(matrix(c(1,2,3), nrow=1, byrow=TRUE))
  funnel(Res_Losses, main= "\nFull Sample")
  funnel(Res_Losses_Male, main = "\nMales Only")
  funnel(Res_Losses_Female, main = "\nFemales Only")
  dev.off() 



##################################################################
## Figure 8. Case Deletion Diagnostics for the Domain of Gains  ##
##################################################################

  
  Inf_Gain_Male_Cooks.d<- Inf_Gain_Male[["inf"]][["cook.d"]]
  Inf_Gain_Male_Cooks.d <- na.omit(Inf_Gain_Male_Cooks.d)
  Inf_Gain_Male_Hat <- Inf_Gain_Male[["inf"]][["hat"]]
  Inf_Gain_Male_Hat <- na.omit(Inf_Gain_Male_Hat)
  Inf_Gain_Male_DFFITS <- Inf_Gain_Male[["inf"]][["dffits"]]
  Inf_Gain_Male_DFFITS <- na.omit( Inf_Gain_Male_DFFITS)
  Inf_Gain_Male_DFBETAS <- Inf_Gain_Male[["dfbs"]][["intrcpt"]]
  Inf_Gain_Male_DFBETAS <- na.omit(Inf_Gain_Male_DFBETAS)
  
  Inf_Gain_Female_Cooks.d<- Inf_Gain_Female[["inf"]][["cook.d"]]
  Inf_Gain_Female_Cooks.d <- na.omit(Inf_Gain_Female_Cooks.d)
  Inf_Gain_Female_Hat <- Inf_Gain_Female[["inf"]][["hat"]]
  Inf_Gain_Female_Hat <- na.omit(Inf_Gain_Female_Hat)
  Inf_Gain_Female_DFFITS <- Inf_Gain_Female[["inf"]][["dffits"]]
  Inf_Gain_Female_DFFITS <- na.omit( Inf_Gain_Female_DFFITS)
  Inf_Gain_Female_DFBETAS <- Inf_Gain_Female[["dfbs"]][["intrcpt"]]
  Inf_Gain_Female_DFBETAS <- na.omit(Inf_Gain_Female_DFBETAS)
  
 
  setEPS(family = "Times") 
  postscript("Figure 8. Case Deletion Diagnostics for the Domain of Gains.eps", width = 9, height = 11, horizontal = FALSE) # The width and height can be adjusted here! 
  par(family="Times")
  par(mar = rep(2, 4))
  layout(matrix(c(0,0,0,0,0,0,
                  1,1,5,5,9,9,
                  1,1,5,5,9,9,
                  2,2,6,6,10,10,
                  2,2,6,6,10,10,
                  3,3,7,7,11,11,
                  3,3,7,7,11,11,
                  4,4,8,8,12,12,
                  4,4,8,8,12,12,
                  0,0,0,0,0,0), nrow=10, byrow=TRUE))
  
  plot(Inf_Gain[["inf"]][["cook.d"]],type="o", pch=19, main = "Cook´s D",xaxt="n",col=ifelse(Inf_Gain[["inf"]][["cook.d"]] >= 0.1575,"lightskyblue4","black"), cex = 1.3 )
  plot(Inf_Gain[["inf"]][["hat"]],type="o", pch=19, main = "Hat Values", xaxt="n", col=ifelse(Inf_Gain[["inf"]][["cook.d"]] >= 0.1575,"lightskyblue4","black"), cex = 1.3 )
  plot(Inf_Gain[["inf"]][["dffits"]],type="o", pch=19, main = "DFFITS", xaxt="n",col=ifelse(Inf_Gain[["inf"]][["cook.d"]] >= 0.1575,"lightskyblue4","black"), cex = 1.3 )
  plot(Inf_Gain[["dfbs"]][["intrcpt"]],type="o", pch=19, main = "DFBETAS",xaxt="n",col=ifelse(Inf_Gain[["inf"]][["cook.d"]] >= 0.1575,"lightskyblue4","black"), cex = 1.3 )
  
  plot(Inf_Gain_Male_Cooks.d,type="o", pch=19, main = "Cook´s D",xaxt="n", col=ifelse(Inf_Gain_Male_Cooks.d>=0.2037,"lightskyblue4","black"), cex = 1.3 )
  plot(Inf_Gain_Male_Hat,type="o", pch=19, main = "Hat Values",xaxt="n",col=ifelse(Inf_Gain_Male_Cooks.d>=0.2037,"lightskyblue4","black"), cex = 1.3 )
  plot(Inf_Gain_Male_DFFITS,type="o", pch=19, main = "DFFITS",xaxt="n",col=ifelse(Inf_Gain_Male_Cooks.d>=0.2037,"lightskyblue4","black"), cex = 1.3 )
  plot(Inf_Gain_Male_DFBETAS,type="o", pch=19, main = "DFBETAS",xaxt="n",col=ifelse(Inf_Gain_Male_Cooks.d>=0.2037,"lightskyblue4","black"), cex = 1.3 )
  
  plot(Inf_Gain_Female_Cooks.d,type="o", pch=19, main = "Cook´s D",xaxt="n", col=ifelse(Inf_Gain_Female_Hat >=0.0628,"lightskyblue4","black" ), cex = 1.3 )
  plot(Inf_Gain_Female_Hat,type="o", pch=19, main = "Hat Values",xaxt="n", col=ifelse(Inf_Gain_Female_Hat >=0.0628,"lightskyblue4","black" ), cex = 1.3 )
  plot(Inf_Gain_Female_DFFITS,type="o", pch=19, main = "DFFITS",xaxt="n", col=ifelse(Inf_Gain_Female_Hat >=0.0628,"lightskyblue4","black" ), cex = 1.3 )
  plot(Inf_Gain_Female_DFBETAS,type="o", pch=19, main = "DFBETAS",xaxt="n", col=ifelse(Inf_Gain_Female_Hat >=0.0628,"lightskyblue4","black" ), cex = 1.3 )
 
 
  mtext("Full Sample", outer = TRUE, line = -8, adj=.13, font=2)
  mtext("Males Only", outer = TRUE, line = -8, adj=.5, font=2)
  mtext("Females Only", outer = TRUE, line = -8, adj=.87, font=2)
  dev.off() 
 
  

##################################################################
## Figure 9. Case Deletion Diagnostics for the Mixed Domain     ##
##################################################################
  
  Inf_Mixed_Male_Cooks.d<- Inf_Mixed_Male[["inf"]][["cook.d"]]
  Inf_Mixed_Male_Cooks.d <- na.omit(Inf_Mixed_Male_Cooks.d)
  Inf_Mixed_Male_Hat <- Inf_Mixed_Male[["inf"]][["hat"]]
  Inf_Mixed_Male_Hat <- na.omit(Inf_Mixed_Male_Hat)
  Inf_Mixed_Male_DFFITS <- Inf_Mixed_Male[["inf"]][["dffits"]]
  Inf_Mixed_Male_DFFITS <- na.omit( Inf_Mixed_Male_DFFITS)
  Inf_Mixed_Male_DFBETAS <- Inf_Mixed_Male[["dfbs"]][["intrcpt"]]
  Inf_Mixed_Male_DFBETAS <- na.omit(Inf_Mixed_Male_DFBETAS)
  
  Inf_Mixed_Female_Cooks.d<- Inf_Mixed_Female[["inf"]][["cook.d"]]
  Inf_Mixed_Female_Cooks.d <- na.omit(Inf_Mixed_Female_Cooks.d)
  Inf_Mixed_Female_Hat <- Inf_Mixed_Female[["inf"]][["hat"]]
  Inf_Mixed_Female_Hat <- na.omit(Inf_Mixed_Female_Hat)
  Inf_Mixed_Female_DFFITS <- Inf_Mixed_Female[["inf"]][["dffits"]]
  Inf_Mixed_Female_DFFITS <- na.omit( Inf_Mixed_Female_DFFITS)
  Inf_Mixed_Female_DFBETAS <- Inf_Mixed_Female[["dfbs"]][["intrcpt"]]
  Inf_Mixed_Female_DFBETAS <- na.omit(Inf_Mixed_Female_DFBETAS)
  
  setEPS(family = "Times") 
  postscript("Figure 9. Case Deletion Diagnostics for the Mixed Domain.eps", width = 9, height = 11, horizontal = FALSE) # The width and height can be adjusted here! 
  par(family="Times")
  par(mar = rep(2, 4))
  layout(matrix(c(0,0,0,0,0,0,
                  1,1,5,5,9,9,
                  1,1,5,5,9,9,
                  2,2,6,6,10,10,
                  2,2,6,6,10,10,
                  3,3,7,7,11,11,
                  3,3,7,7,11,11,
                  4,4,8,8,12,12,
                  4,4,8,8,12,12,
                  0,0,0,0,0,0), nrow=10, byrow=TRUE))
  
  plot(Inf_Mixed[["inf"]][["cook.d"]],type="o", pch=19, main = "Cook´s D",xaxt="n",col=ifelse(Inf_Mixed[["inf"]][["cook.d"]] >= 0.2011,"lightskyblue4","black"), cex = 1.3 )
  plot(Inf_Mixed[["inf"]][["hat"]],type="o", pch=19, main = "Hat Values", xaxt="n", col=ifelse(Inf_Mixed[["inf"]][["cook.d"]] >= 0.2011,"lightskyblue4","black"), cex = 1.3 )
  plot(Inf_Mixed[["inf"]][["dffits"]],type="o", pch=19, main = "DFFITS", xaxt="n",col=ifelse(Inf_Mixed[["inf"]][["cook.d"]] >= 0.2011,"lightskyblue4","black"), cex = 1.3 )
  plot(Inf_Mixed[["dfbs"]][["intrcpt"]],type="o", pch=19, main = "DFBETAS",xaxt="n",col=ifelse(Inf_Mixed[["inf"]][["cook.d"]] >= 0.2011,"lightskyblue4","black"), cex = 1.3 )
  
  plot(Inf_Mixed_Male_Cooks.d,type="o", pch=19, main = "Cook´s D",xaxt="n", cex = 1.3 )
  plot(Inf_Mixed_Male_Hat,type="o", pch=19, main = "Hat Values",xaxt="n", cex = 1.3 )
  plot(Inf_Mixed_Male_DFFITS,type="o", pch=19, main = "DFFITS",xaxt="n", cex = 1.3 )
  plot(Inf_Mixed_Male_DFBETAS,type="o", pch=19, main = "DFBETAS",xaxt="n", cex = 1.3 )
  
  plot(Inf_Mixed_Female_Cooks.d,type="o", pch=19, main = "Cook´s D",xaxt="n", col=ifelse(Inf_Mixed_Female_Cooks.d  >= 0.1804,"lightskyblue4","black" ), cex = 1.3 )
  plot(Inf_Mixed_Female_Hat,type="o", pch=19, main = "Hat Values",xaxt="n", col=ifelse(Inf_Mixed_Female_Cooks.d  >= 0.1804,"lightskyblue4","black" ), cex = 1.3 )
  plot(Inf_Mixed_Female_DFFITS,type="o", pch=19, main = "DFFITS",xaxt="n", col=ifelse(Inf_Mixed_Female_Cooks.d  >= 0.1804,"lightskyblue4","black" ), cex = 1.3 )
  plot(Inf_Mixed_Female_DFBETAS,type="o", pch=19, main = "DFBETAS",xaxt="n", col=ifelse(Inf_Mixed_Female_Cooks.d  >= 0.1804,"lightskyblue4","black" ), cex = 1.3 )
  

  mtext("Full Sample", outer = TRUE, line = -8, adj=.13, font=2)
  mtext("Males Only", outer = TRUE, line = -8, adj=.5, font=2)
  mtext("Females Only", outer = TRUE, line = -8, adj=.87, font=2)
  dev.off()

  
 

###################################################################
## Figure 10. Case Deletion Diagnostics for the Domain of Losses ##
###################################################################

  Inf_Losses_Male_Cooks.d<- Inf_Losses_Male[["inf"]][["cook.d"]]
  Inf_Losses_Male_Cooks.d <- na.omit(Inf_Losses_Male_Cooks.d)
  Inf_Losses_Male_Hat <- Inf_Losses_Male[["inf"]][["hat"]]
  Inf_Losses_Male_Hat <- na.omit(Inf_Losses_Male_Hat)
  Inf_Losses_Male_DFFITS <- Inf_Losses_Male[["inf"]][["dffits"]]
  Inf_Losses_Male_DFFITS <- na.omit( Inf_Losses_Male_DFFITS)
  Inf_Losses_Male_DFBETAS <- Inf_Losses_Male[["dfbs"]][["intrcpt"]]
  Inf_Losses_Male_DFBETAS <- na.omit(Inf_Losses_Male_DFBETAS)
  
  Inf_Losses_Female_Cooks.d<- Inf_Losses_Female[["inf"]][["cook.d"]]
  Inf_Losses_Female_Cooks.d <- na.omit(Inf_Losses_Female_Cooks.d)
  Inf_Losses_Female_Hat <- Inf_Losses_Female[["inf"]][["hat"]]
  Inf_Losses_Female_Hat <- na.omit(Inf_Losses_Female_Hat)
  Inf_Losses_Female_DFFITS <- Inf_Losses_Female[["inf"]][["dffits"]]
  Inf_Losses_Female_DFFITS <- na.omit( Inf_Losses_Female_DFFITS)
  Inf_Losses_Female_DFBETAS <- Inf_Losses_Female[["dfbs"]][["intrcpt"]]
  Inf_Losses_Female_DFBETAS <- na.omit(Inf_Losses_Female_DFBETAS)
  
  setEPS(family = "Times") 
  postscript("Figure 10. Case Deletion Diagnostics for the Domain of Losses.eps", width = 9, height = 11, horizontal = FALSE) # The width and height can be adjusted here! 
  par(family="Times")
  par(mar = rep(2, 4))
  layout(matrix(c(0,0,0,0,0,0,
                  1,1,5,5,9,9,
                  1,1,5,5,9,9,
                  2,2,6,6,10,10,
                  2,2,6,6,10,10,
                  3,3,7,7,11,11,
                  3,3,7,7,11,11,
                  4,4,8,8,12,12,
                  4,4,8,8,12,12,
                  0,0,0,0,0,0), nrow=10, byrow=TRUE))
  
  plot(Inf_Losses[["inf"]][["cook.d"]],type="o", pch=19, main = "Cook´s D",xaxt="n", cex = 1.3 )
  plot(Inf_Losses[["inf"]][["hat"]],type="o", pch=19, main = "Hat Values", xaxt="n", cex = 1.3 )
  plot(Inf_Losses[["inf"]][["dffits"]],type="o", pch=19, main = "DFFITS", xaxt="n", cex = 1.3 )
  plot(Inf_Losses[["dfbs"]][["intrcpt"]],type="o", pch=19, main = "DFBETAS",xaxt="n", cex = 1.3 )
  
  
  x <- c(1,2,3,4,5,6,7,8)
  col.line <- c('black','black','black','black','black','black','black','black')
  col.point <-c('lightskyblue4','black','black','black','black','black','black','black')
  y <- Inf_Losses_Male_Cooks.d
  z <- Inf_Losses_Male_Hat
  q <- Inf_Losses_Male_DFFITS
  c <- Inf_Losses_Male_DFBETAS
  plot(x,y,type="o", pch=19, main = "Cook´s D",xaxt="n", col=col.point, cex = 1.3 )
  segments(x[-length(x)],y[-length(y)],x[-1L],y[-1L],col=col.line, cex = 1.3 )
  plot(x,z,type="o", pch=19, main = "Hat Values",xaxt="n",col=col.point, cex = 1.3 )
  segments(x[-length(x)],z[-length(z)],x[-1L],z[-1L],col=col.line, cex = 1.3 )
  plot(x,q,type="o", pch=19, main = "DFFITS",xaxt="n",col=col.point, cex = 1.3 )
  segments(x[-length(x)],q[-length(q)],x[-1L],q[-1L],col=col.line, cex = 1.3 )
  plot(x,c,type="o", pch=19, main = "DFBETAS",xaxt="n",col=col.point, cex = 1.3 )
  segments(x[-length(x)],c[-length(c)],x[-1L],c[-1L],col=col.line, cex = 1.3 )
  
  plot(Inf_Losses_Female_Cooks.d,type="o", pch=19, main = "Cook´s D",xaxt="n", cex = 1.3 )
  plot(Inf_Losses_Female_Hat,type="o", pch=19, main = "Hat Values",xaxt="n", cex = 1.3 )
  plot(Inf_Losses_Female_DFFITS,type="o", pch=19, main = "DFFITS",xaxt="n", cex = 1.3 )
  plot(Inf_Losses_Female_DFBETAS,type="o", pch=19, main = "DFBETAS",xaxt="n, cex = 1.3 ")
  

  mtext("Full Sample", outer = TRUE, line = -8, adj=.13, font=2)
  mtext("Males Only", outer = TRUE, line = -8, adj=.5, font=2)
  mtext("Females Only", outer = TRUE, line = -8, adj=.87, font=2)
  dev.off()
  



  
  


